@@ -10,14 +10,14 @@
 
 #include "ui_rdppreferences.h"
 
-K_PLUGIN_FACTORY_WITH_JSON(KrdcKcmFactory, "krdc_rdp_config.json", registerPlugin<RdpPreferences>();)
+K_PLUGIN_CLASS(RdpPreferences)
 
 RdpPreferences::RdpPreferences(QWidget *parent, const QVariantList &args)
         : KCModule(parent, args)
 {
     Ui::RdpPreferences rdpUi;
     rdpUi.setupUi(this);
-    // would need a lot of code duplication. find a solution, bit it's not
+    // would need a lot of code duplication. find a solution, but it's not
     // that important because you will not change this configuration each day...
     // see rdp/rdphostpreferences.cpp
     rdpUi.kcfg_Resolution->hide();
